@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2007 Loïc Corbasson <loic.corbasson@gmail.com>
+  SPDX-FileCopyrightText: 2007 Loïc Corbasson <loic.corbasson@gmail.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef EVENTVIEWS_CALENDARDECORATION_H
 #define EVENTVIEWS_CALENDARDECORATION_H
@@ -28,8 +15,10 @@
 #include <QDate>
 #include <QPixmap>
 
-namespace EventViews {
-namespace CalendarDecoration {
+namespace EventViews
+{
+namespace CalendarDecoration
+{
 /**
   @class Element
 
@@ -43,7 +32,7 @@ class EVENTVIEWS_EXPORT Element : public QObject
     Q_OBJECT
 
 public:
-    typedef QList<Element *> List;
+    using List = QList<Element *>;
 
     explicit Element(const QString &id);
     ~Element() override;
@@ -53,18 +42,18 @@ public:
       This will be used for example for internal configuration (position, etc.),
       so don't i18n it and make it unique for your decoration.
     */
-    virtual QString id() const;
+    Q_REQUIRED_RESULT virtual QString id() const;
 
     /**
       Description of element.
     */
-    virtual QString elementInfo() const;
+    Q_REQUIRED_RESULT virtual QString elementInfo() const;
 
     /**
       Return a short text for a given date,
       usually only a few words.
     */
-    virtual QString shortText();
+    Q_REQUIRED_RESULT virtual QString shortText();
 
     /**
       Return a long text for a given date.
@@ -73,32 +62,32 @@ public:
 
       Can for example be used as a tool tip.
     */
-    virtual QString longText();
+    Q_REQUIRED_RESULT virtual QString longText();
 
     /**
       Return an extensive text for a given date.
       This text can be of any length,
       but usually it will have one or a few paragraphs.
     */
-    virtual QString extensiveText();
+    Q_REQUIRED_RESULT virtual QString extensiveText();
 
     /**
       Return a pixmap for a given date and a given size.
     */
-    virtual QPixmap newPixmap(const QSize &);
+    Q_REQUIRED_RESULT virtual QPixmap newPixmap(const QSize &);
 
     /**
       Return a URL pointing to more information about the content of the
       element.
      */
-    virtual QUrl url();
+    Q_REQUIRED_RESULT virtual QUrl url();
 
 Q_SIGNALS:
-    void gotNewPixmap(const QPixmap &) const;
-    void gotNewShortText(const QString &) const;
-    void gotNewLongText(const QString &) const;
-    void gotNewExtensiveText(const QString &) const;
-    void gotNewUrl(const QUrl &) const;
+    void gotNewPixmap(const QPixmap &);
+    void gotNewShortText(const QString &);
+    void gotNewLongText(const QString &);
+    void gotNewExtensiveText(const QString &);
+    void gotNewUrl(const QUrl &);
 
 protected:
     QString mId;
@@ -115,8 +104,7 @@ public:
     explicit StoredElement(const QString &id);
     StoredElement(const QString &id, const QString &shortText);
     StoredElement(const QString &id, const QString &shortText, const QString &longText);
-    StoredElement(const QString &id, const QString &shortText, const QString &longText,
-                  const QString &extensiveText);
+    StoredElement(const QString &id, const QString &shortText, const QString &longText, const QString &extensiveText);
     StoredElement(const QString &id, const QPixmap &pixmap);
 
     virtual void setShortText(const QString &t);
@@ -163,7 +151,7 @@ public:
         return QStringLiteral("Calendar/Decoration");
     }
 
-    typedef QList<Decoration *> List;
+    using List = QList<Decoration *>;
 
     Decoration();
     ~Decoration() override;
