@@ -12,18 +12,19 @@
 
 #include <QFrame>
 
-namespace EventViews {
+namespace EventViews
+{
 class Agenda;
 class TimeLabelsZone;
 
 class Prefs;
-typedef QSharedPointer<Prefs> PrefsPtr;
+using PrefsPtr = QSharedPointer<Prefs>;
 
 class TimeLabels : public QFrame
 {
     Q_OBJECT
 public:
-    typedef QList<TimeLabels *> List;
+    using List = QList<TimeLabels *>;
 
     TimeLabels(const QTimeZone &zone, int rows, TimeLabelsZone *parent = nullptr, Qt::WindowFlags f = {});
 
@@ -79,7 +80,7 @@ private:
     Agenda *mAgenda = nullptr;
     TimeLabelsZone *mTimeLabelsZone = nullptr;
 
-    QFrame *mMousePos = nullptr;  // shows a marker for the current mouse position in y direction
+    QFrame *mMousePos = nullptr; // shows a marker for the current mouse position in y direction
 };
 }
 
