@@ -19,8 +19,8 @@
 #include <KCalUtils/IncidenceFormatter>
 #include <KCalUtils/RecurrenceActions>
 
-#include <KMessageBox>
 #include "calendarview_debug.h"
+#include <KMessageBox>
 
 using namespace EventViews;
 using namespace KCalendarCore;
@@ -57,22 +57,21 @@ void MonthItem::updateMonthGraphicsItems()
 
     // For each row of the month view, create an item to build the whole
     // MonthItem's MonthGraphicsItems.
-    for (QDate d = mMonthScene->mMonthView->actualStartDateTime().date();
-         d < mMonthScene->mMonthView->actualEndDateTime().date(); d = d.addDays(7)) {
+    for (QDate d = mMonthScene->mMonthView->actualStartDateTime().date(); d < mMonthScene->mMonthView->actualEndDateTime().date(); d = d.addDays(7)) {
         QDate end = d.addDays(6);
 
         int span;
         QDate start;
-        if (monthStartDate <= d && monthEndDate >= end) {   // MonthItem takes the whole line
+        if (monthStartDate <= d && monthEndDate >= end) { // MonthItem takes the whole line
             span = 6;
             start = d;
-        } else if (monthStartDate >= d && monthEndDate <= end) {   // starts and ends on this line
+        } else if (monthStartDate >= d && monthEndDate <= end) { // starts and ends on this line
             start = monthStartDate;
             span = daySpan();
-        } else if (d <= monthEndDate && monthEndDate <= end) {   // MonthItem ends on this line
+        } else if (d <= monthEndDate && monthEndDate <= end) { // MonthItem ends on this line
             span = mMonthScene->getLeftSpan(monthEndDate);
             start = d;
-        } else if (d <= monthStartDate && monthStartDate <= end) {   // MonthItem begins on this line
+        } else if (d <= monthStartDate && monthStartDate <= end) { // MonthItem begins on this line
             span = mMonthScene->getRightSpan(monthStartDate);
             start = monthStartDate;
         } else { // MonthItem is not on the line
@@ -80,7 +79,7 @@ void MonthItem::updateMonthGraphicsItems()
         }
 
         // A new item needs to be created
-        auto *newItem = new MonthGraphicsItem(this);
+        auto newItem = new MonthGraphicsItem(this);
         mMonthGraphicsItemList << newItem;
         newItem->setStartDate(start);
         newItem->setDaySpan(span);
@@ -239,7 +238,7 @@ bool MonthItem::greaterThan(const MonthItem *e1, const MonthItem *e2)
 
 bool MonthItem::greaterThanFallback(const MonthItem *other) const
 {
-    const auto *h = qobject_cast<const HolidayMonthItem *>(other);
+    const auto h = qobject_cast<const HolidayMonthItem *>(other);
 
     // If "other" is a holiday, display it first.
     return !h;
@@ -281,7 +280,10 @@ QList<MonthGraphicsItem *> EventViews::MonthItem::monthGraphicsItems() const
 
 //-----------------------------------------------------------------
 // INCIDENCEMONTHITEM
-IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene, const Akonadi::ETMCalendar::Ptr &calendar, const Akonadi::Item &aitem, const KCalendarCore::Incidence::Ptr &incidence,
+IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene,
+                                       const Akonadi::ETMCalendar::Ptr &calendar,
+                                       const Akonadi::Item &aitem,
+                                       const KCalendarCore::Incidence::Ptr &incidence,
                                        const QDate &recurStartDate)
     : MonthItem(monthScene)
     , mCalendar(calendar)
@@ -293,8 +295,7 @@ IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene, const Akonadi::ET
     mIsTodo = CalendarSupport::hasTodo(aitem);
 
     KCalendarCore::Incidence::Ptr inc = mIncidence;
-    if (inc->customProperty("KABC", "BIRTHDAY") == QLatin1String("YES")
-        || inc->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
+    if (inc->customProperty("KABC", "BIRTHDAY") == QLatin1String("YES") || inc->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
         const int years = EventViews::yearDiff(inc->dtStart().date(), recurStartDate);
         if (years > 0) {
             inc = KCalendarCore::Incidence::Ptr(inc->clone());
@@ -305,13 +306,11 @@ IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene, const Akonadi::ET
         }
     }
 
-    connect(monthScene, &MonthScene::incidenceSelected,
-            this, &IncidenceMonthItem::updateSelection);
+    connect(monthScene, &MonthScene::incidenceSelected, this, &IncidenceMonthItem::updateSelection);
 
     // first set to 0, because it's used in startDate()
     mRecurDayOffset = 0;
-    if ((mIncidence->recurs() || mIncidence->recurrenceId().isValid())
-        && startDate().isValid() && recurStartDate.isValid()) {
+    if ((mIncidence->recurs() || mIncidence->recurrenceId().isValid()) && startDate().isValid() && recurStartDate.isValid()) {
         mRecurDayOffset = startDate().daysTo(recurStartDate);
     }
 }
@@ -322,7 +321,7 @@ IncidenceMonthItem::~IncidenceMonthItem()
 
 bool IncidenceMonthItem::greaterThanFallback(const MonthItem *other) const
 {
-    const auto *o = qobject_cast<const IncidenceMonthItem *>(other);
+    const auto o = qobject_cast<const IncidenceMonthItem *>(other);
     if (!o) {
         return MonthItem::greaterThanFallback(other);
     }
@@ -343,7 +342,7 @@ bool IncidenceMonthItem::greaterThanFallback(const MonthItem *other) const
 QDate IncidenceMonthItem::realStartDate() const
 {
     if (!mIncidence) {
-        return QDate();
+        return {};
     }
 
     const QDateTime dt = mIncidence->dateTime(Incidence::RoleDisplayStart);
@@ -355,7 +354,7 @@ QDate IncidenceMonthItem::realStartDate() const
 QDate IncidenceMonthItem::realEndDate() const
 {
     if (!mIncidence) {
-        return QDate();
+        return {};
     }
 
     QDateTime dt = mIncidence->dateTime(KCalendarCore::Incidence::RoleDisplayEnd);
@@ -375,15 +374,12 @@ bool IncidenceMonthItem::allDay() const
 
 bool IncidenceMonthItem::isMoveable() const
 {
-    return monthScene()->mMonthView->calendar()->hasRight(akonadiItem(),
-                                                          Akonadi::Collection::CanChangeItem);
+    return monthScene()->mMonthView->calendar()->hasRight(akonadiItem(), Akonadi::Collection::CanChangeItem);
 }
 
 bool IncidenceMonthItem::isResizable() const
 {
-    return mIsEvent && monthScene()->mMonthView->calendar()->hasRight(
-        akonadiItem(),
-        Akonadi::Collection::CanChangeItem);
+    return mIsEvent && monthScene()->mMonthView->calendar()->hasRight(akonadiItem(), Akonadi::Collection::CanChangeItem);
 }
 
 void IncidenceMonthItem::finalizeMove(const QDate &newStartDate)
@@ -391,8 +387,7 @@ void IncidenceMonthItem::finalizeMove(const QDate &newStartDate)
     Q_ASSERT(isMoveable());
 
     if (startDate().isValid() && newStartDate.isValid()) {
-        updateDates(startDate().daysTo(newStartDate),
-                    startDate().daysTo(newStartDate));
+        updateDates(startDate().daysTo(newStartDate), startDate().daysTo(newStartDate));
     }
 }
 
@@ -400,10 +395,8 @@ void IncidenceMonthItem::finalizeResize(const QDate &newStartDate, const QDate &
 {
     Q_ASSERT(isResizable());
 
-    if (startDate().isValid() && endDate().isValid()
-        && newStartDate.isValid() && newEndDate.isValid()) {
-        updateDates(startDate().daysTo(newStartDate),
-                    endDate().daysTo(newEndDate));
+    if (startDate().isValid() && endDate().isValid() && newStartDate.isValid() && newEndDate.isValid()) {
+        updateDates(startDate().daysTo(newStartDate), endDate().daysTo(newEndDate));
     }
 }
 
@@ -420,8 +413,7 @@ void IncidenceMonthItem::updateDates(int startOffset, int endOffset)
     if (mIncidence->recurs()) {
         const int res = monthScene()->mMonthView->showMoveRecurDialog(mIncidence, startDate());
         switch (res) {
-        case KCalUtils::RecurrenceActions::AllOccurrences:
-        {
+        case KCalUtils::RecurrenceActions::AllOccurrences: {
             // All occurrences
             KCalendarCore::Incidence::Ptr oldIncidence(mIncidence->clone());
             setNewDates(mIncidence, startOffset, endOffset);
@@ -429,24 +421,21 @@ void IncidenceMonthItem::updateDates(int startOffset, int endOffset)
             break;
         }
         case KCalUtils::RecurrenceActions::SelectedOccurrence: // Just this occurrence
-        case KCalUtils::RecurrenceActions::FutureOccurrences:
-        {                                                       // All future occurrences
+        case KCalUtils::RecurrenceActions::FutureOccurrences: { // All future occurrences
             const bool thisAndFuture = (res == KCalUtils::RecurrenceActions::FutureOccurrences);
             QDateTime occurrenceDate(mIncidence->dtStart());
             occurrenceDate.setDate(startDate());
-            KCalendarCore::Incidence::Ptr newIncidence(KCalendarCore::Calendar::createException(
-                                                      mIncidence, occurrenceDate, thisAndFuture));
+            KCalendarCore::Incidence::Ptr newIncidence(KCalendarCore::Calendar::createException(mIncidence, occurrenceDate, thisAndFuture));
             if (newIncidence) {
                 changer->startAtomicOperation(i18n("Move occurrence(s)"));
                 setNewDates(newIncidence, startOffset, endOffset);
                 changer->createIncidence(newIncidence, item.parentCollection(), parentWidget());
                 changer->endAtomicOperation();
             } else {
-                KMessageBox::sorry(
-                    parentWidget(),
-                    i18n("Unable to add the exception item to the calendar. "
-                         "No change will be done."),
-                    i18n("Error Occurred"));
+                KMessageBox::sorry(parentWidget(),
+                                   i18n("Unable to add the exception item to the calendar. "
+                                        "No change will be done."),
+                                   i18n("Error Occurred"));
             }
             break;
         }
@@ -460,15 +449,14 @@ void IncidenceMonthItem::updateDates(int startOffset, int endOffset)
 
 void IncidenceMonthItem::updateSelection(const Akonadi::Item &incidence, const QDate &date)
 {
-    Q_UNUSED(date);
+    Q_UNUSED(date)
     setSelected(incidence == akonadiItem());
 }
 
 QString IncidenceMonthItem::text(bool end) const
 {
     QString ret = mIncidence->summary();
-    if (!allDay() && !mIsJournal
-        && monthScene()->monthView()->preferences()->showTimeInMonthView()) {
+    if (!allDay() && !mIsJournal && monthScene()->monthView()->preferences()->showTimeInMonthView()) {
         // Prepend the time str to the text
         QString timeStr;
         if (mIsTodo) {
@@ -486,8 +474,7 @@ QString IncidenceMonthItem::text(bool end) const
                 timeStr = QLocale().toString(time, QLocale::ShortFormat);
             } else {
                 KCalendarCore::Event::Ptr event = mIncidence.staticCast<Event>();
-                timeStr = QLocale().toString(
-                    event->dtEnd().toLocalTime().time(), QLocale::ShortFormat);
+                timeStr = QLocale().toString(event->dtEnd().toLocalTime().time(), QLocale::ShortFormat);
             }
         }
         if (!timeStr.isEmpty()) {
@@ -504,9 +491,7 @@ QString IncidenceMonthItem::text(bool end) const
 
 QString IncidenceMonthItem::toolTipText(const QDate &date) const
 {
-    return KCalUtils::IncidenceFormatter::toolTipStr(
-        CalendarSupport::displayName(mCalendar.data(), akonadiItem().parentCollection()),
-        mIncidence, date, true);
+    return KCalUtils::IncidenceFormatter::toolTipStr(CalendarSupport::displayName(mCalendar.data(), akonadiItem().parentCollection()), mIncidence, date, true);
 }
 
 QVector<QPixmap> IncidenceMonthItem::icons() const
@@ -520,14 +505,12 @@ QVector<QPixmap> IncidenceMonthItem::icons() const
     bool specialEvent = false;
     Akonadi::Item item = akonadiItem();
 
-    const QSet<EventView::ItemIcon> icons
-        = monthScene()->monthView()->preferences()->monthViewIcons();
+    const QSet<EventView::ItemIcon> icons = monthScene()->monthView()->preferences()->monthViewIcons();
 
     QString customIconName;
     if (icons.contains(EventViews::EventView::CalendarCustomIcon)) {
         const QString iconName = monthScene()->monthView()->iconForItem(item);
-        if (!iconName.isEmpty() && iconName != QLatin1String("view-calendar")
-            && iconName != QLatin1String("office-calendar")) {
+        if (!iconName.isEmpty() && iconName != QLatin1String("view-calendar") && iconName != QLatin1String("office-calendar")) {
             customIconName = iconName;
             ret << QPixmap(cachedSmallIcon(iconName));
         }
@@ -541,7 +524,7 @@ QVector<QPixmap> IncidenceMonthItem::icons() const
             specialEvent = true;
             // Disabling birthday icon because it's the birthday agent's icon
             // and we allow to display the agent's icon now.
-            //ret << monthScene()->birthdayPixmap();
+            // ret << monthScene()->birthdayPixmap();
         }
 
         // smartins: Disabling the event Pixmap because:
@@ -552,9 +535,7 @@ QVector<QPixmap> IncidenceMonthItem::icons() const
         //    from event's much easier.
 
         // ret << monthScene()->eventPixmap();
-    } else if ((mIsTodo || mIsJournal) && icons.contains(mIsTodo
-                                                         ? EventView::TaskIcon
-                                                         : EventView::JournalIcon)) {
+    } else if ((mIsTodo || mIsJournal) && icons.contains(mIsTodo ? EventView::TaskIcon : EventView::JournalIcon)) {
         QDateTime occurrenceDateTime = mIncidence->dateTime(Incidence::RoleRecurrenceStart);
         occurrenceDateTime.setDate(realStartDate());
 
@@ -564,23 +545,19 @@ QVector<QPixmap> IncidenceMonthItem::icons() const
         }
     }
 
-    if (icons.contains(EventView::ReadOnlyIcon)
-        && !monthScene()->mMonthView->calendar()->hasRight(item, Akonadi::Collection::CanChangeItem)
-        && !specialEvent) {
+    if (icons.contains(EventView::ReadOnlyIcon) && !monthScene()->mMonthView->calendar()->hasRight(item, Akonadi::Collection::CanChangeItem) && !specialEvent) {
         ret << monthScene()->readonlyPixmap();
     }
 
     /* sorry, this looks too cluttered. disable until we can
        make something prettier; no idea at this time -- allen */
-    if (icons.contains(EventView::ReminderIcon)
-        && mIncidence->hasEnabledAlarms() && !specialEvent) {
+    if (icons.contains(EventView::ReminderIcon) && mIncidence->hasEnabledAlarms() && !specialEvent) {
         ret << monthScene()->alarmPixmap();
     }
-    if (icons.contains(EventView::RecurringIcon)
-        && mIncidence->recurs() && !specialEvent) {
+    if (icons.contains(EventView::RecurringIcon) && mIncidence->recurs() && !specialEvent) {
         ret << monthScene()->recurPixmap();
     }
-    //TODO: check what to do with Reply
+    // TODO: check what to do with Reply
 
     return ret;
 }
@@ -624,8 +601,7 @@ QColor IncidenceMonthItem::bgColor() const
     }
 
     const auto &colorPreference = prefs->monthViewColors();
-    const auto bgDisplaysResource = colorPreference == PrefsBase::MonthItemResourceInsideCategoryOutside
-                                    || colorPreference == PrefsBase::MonthItemResourceOnly;
+    const auto bgDisplaysResource = colorPreference == PrefsBase::MonthItemResourceInsideCategoryOutside || colorPreference == PrefsBase::MonthItemResourceOnly;
     return bgDisplaysResource ? EventViews::resourceColor(akonadiItem(), prefs) : catColor();
 }
 
@@ -633,8 +609,7 @@ QColor IncidenceMonthItem::frameColor() const
 {
     const auto &prefs = monthScene()->monthView()->preferences();
     const auto frameDisplaysResource =
-        (prefs->monthViewColors() == PrefsBase::MonthItemResourceOnly
-         || prefs->monthViewColors() == PrefsBase::MonthItemCategoryInsideResourceOutside);
+        (prefs->monthViewColors() == PrefsBase::MonthItemResourceOnly || prefs->monthViewColors() == PrefsBase::MonthItemCategoryInsideResourceOutside);
     const auto frameColor = frameDisplaysResource ? EventViews::resourceColor(akonadiItem(), prefs) : catColor();
     return EventView::itemFrameColor(frameColor, selected());
 }
@@ -669,7 +644,7 @@ void IncidenceMonthItem::setNewDates(const KCalendarCore::Incidence::Ptr &incide
         KCalendarCore::Todo::Ptr todo = incidence.staticCast<Todo>();
         QDateTime due = todo->dtDue();
         QDateTime start = todo->dtStart();
-        if (due.isValid()) {   // Due has priority over start.
+        if (due.isValid()) { // Due has priority over start.
             // We will only move the due date, unlike events where we move both.
             due = due.addDays(offset);
             todo->setDtDue(due);
@@ -684,8 +659,7 @@ void IncidenceMonthItem::setNewDates(const KCalendarCore::Incidence::Ptr &incide
             todo->setDtStart(start);
         } else {
             // This never happens
-            qCWarning(CALENDARVIEW_LOG) << "Move what? uid:" << todo->uid() << "; summary="
-                                        << todo->summary();
+            qCWarning(CALENDARVIEW_LOG) << "Move what? uid:" << todo->uid() << "; summary=" << todo->summary();
         }
     } else {
         incidence->setDtStart(incidence->dtStart().addDays(startOffset));
@@ -711,7 +685,7 @@ HolidayMonthItem::~HolidayMonthItem()
 
 bool HolidayMonthItem::greaterThanFallback(const MonthItem *other) const
 {
-    const auto *o = qobject_cast<const HolidayMonthItem *>(other);
+    const auto o = qobject_cast<const HolidayMonthItem *>(other);
     if (o) {
         return MonthItem::greaterThanFallback(other);
     }
@@ -722,14 +696,14 @@ bool HolidayMonthItem::greaterThanFallback(const MonthItem *other) const
 
 void HolidayMonthItem::finalizeMove(const QDate &newStartDate)
 {
-    Q_UNUSED(newStartDate);
+    Q_UNUSED(newStartDate)
     Q_ASSERT(false);
 }
 
 void HolidayMonthItem::finalizeResize(const QDate &newStartDate, const QDate &newEndDate)
 {
-    Q_UNUSED(newStartDate);
-    Q_UNUSED(newEndDate);
+    Q_UNUSED(newStartDate)
+    Q_UNUSED(newEndDate)
     Q_ASSERT(false);
 }
 
