@@ -17,13 +17,25 @@
 namespace EventViews
 {
 /**
-  This class provides a view ....
+  This class provides a view showing which blocks of time are occupied by events
+  in the user's calendars.
 */
 class EVENTVIEWS_EXPORT TimelineView : public EventView
 {
     Q_OBJECT
 public:
+
+    /**
+     * Create a TimelineView.
+     * @param preferences Preferences object for user-configurable aspects of the view.
+     */
+    explicit TimelineView(const EventViews::PrefsPtr &preferences, QWidget *parent = nullptr);
+
+    /**
+     * @deprecated Use TimelineView(const EventViews::PrefsPtr &preferences, QWidget *parent = nullptr)
+     */
     explicit TimelineView(QWidget *parent = nullptr);
+
     ~TimelineView() override;
 
     Q_REQUIRED_RESULT Akonadi::Item::List selectedIncidences() const override;
@@ -33,9 +45,14 @@ public:
     // ensure start and end are valid before calling this.
     void showDates(const QDate &, const QDate &, const QDate &preferredMonth = QDate()) override;
 
-    // FIXME: we already have startDateTime() in the base class
-    // why aren't we using it.
+    // Unused.
+    /** @deprecated Use EventView::startDateTime. */
+    [[deprecated("Use EventView::startDateTime.")]]
     Q_REQUIRED_RESULT QDate startDate() const;
+
+    // Unused.
+    /** @deprecated Use EventView::endDateTime.   */
+    [[deprecated("Use EventView::endDateTime.")]]
     Q_REQUIRED_RESULT QDate endDate() const;
 
     void showIncidences(const Akonadi::Item::List &incidenceList, const QDate &date) override;
