@@ -5,27 +5,26 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#include "todomodel_p.h"
 #include "incidencetreemodel.h"
+#include "todomodel_p.h"
 
-#include <CalendarSupport/Utils>
 #include <CalendarSupport/KCalPrefs>
-#include <KLocalizedString>
-#include <KCalendarCore/Event>
-#include <KCalendarCore/Attachment>
+#include <CalendarSupport/Utils>
 #include <KCalUtils/IncidenceFormatter>
+#include <KCalendarCore/Attachment>
+#include <KCalendarCore/Event>
 #include <KEmailAddress>
+#include <KLocalizedString>
 
 #include <KCalUtils/DndFactory>
 #include <KCalUtils/ICalDrag>
 #include <KCalUtils/VCalDrag>
 
-
-#include <KMessageBox>
 #include "calendarview_debug.h"
+#include <KMessageBox>
 
-#include <QMimeData>
 #include <QIcon>
+#include <QMimeData>
 
 struct SourceModelIndex {
     SourceModelIndex(int _r, int _c, void *_p, QAbstractItemModel *_m)
@@ -51,7 +50,8 @@ static bool isDueToday(const KCalendarCore::Todo::Ptr &todo)
     return !todo->isCompleted() && todo->dtDue().date() == QDate::currentDate();
 }
 
-TodoModel::Private::Private(const EventViews::PrefsPtr &preferences, TodoModel *qq) : QObject()
+TodoModel::Private::Private(const EventViews::PrefsPtr &preferences, TodoModel *qq)
+    : QObject()
     , m_preferences(preferences)
     , q(qq)
 {
@@ -60,8 +60,8 @@ TodoModel::Private::Private(const EventViews::PrefsPtr &preferences, TodoModel *
 Akonadi::Item TodoModel::Private::findItemByUid(const QString &uid, const QModelIndex &parent) const
 {
     Q_ASSERT(!uid.isEmpty());
-    auto *treeModel = qobject_cast<IncidenceTreeModel *>(q->sourceModel());
-    if (treeModel) {   // O(1) Shortcut
+    auto treeModel = qobject_cast<IncidenceTreeModel *>(q->sourceModel());
+    if (treeModel) { // O(1) Shortcut
         return treeModel->item(uid);
     }
 
@@ -102,7 +102,7 @@ void TodoModel::Private::onHeaderDataChanged(Qt::Orientation orientation, int fi
 void TodoModel::Private::onRowsAboutToBeInserted(const QModelIndex &parent, int begin, int end)
 {
     const QModelIndex index = q->mapFromSource(parent);
-    Q_ASSERT(!(parent.isValid() ^ index.isValid()));     // Both must be valid, or both invalid
+    Q_ASSERT(!(parent.isValid() ^ index.isValid())); // Both must be valid, or both invalid
     Q_ASSERT(!(index.isValid() && index.model() != q));
 
     q->beginInsertRows(index, begin, end);
@@ -116,7 +116,7 @@ void TodoModel::Private::onRowsInserted(const QModelIndex &, int, int)
 void TodoModel::Private::onRowsAboutToBeRemoved(const QModelIndex &parent, int begin, int end)
 {
     const QModelIndex index = q->mapFromSource(parent);
-    Q_ASSERT(!(parent.isValid() ^ index.isValid()));     // Both must be valid, or both invalid
+    Q_ASSERT(!(parent.isValid() ^ index.isValid())); // Both must be valid, or both invalid
     Q_ASSERT(!(index.isValid() && index.model() != q));
 
     q->beginRemoveRows(index, begin, end);
@@ -127,15 +127,17 @@ void TodoModel::Private::onRowsRemoved(const QModelIndex &, int, int)
     q->endRemoveRows();
 }
 
-void TodoModel::Private::onRowsAboutToBeMoved(const QModelIndex &sourceParent, int sourceStart,
-                                              int sourceEnd, const QModelIndex &destinationParent,
+void TodoModel::Private::onRowsAboutToBeMoved(const QModelIndex &sourceParent,
+                                              int sourceStart,
+                                              int sourceEnd,
+                                              const QModelIndex &destinationParent,
                                               int destinationRow)
 {
-    Q_UNUSED(sourceParent);
-    Q_UNUSED(sourceStart);
-    Q_UNUSED(sourceEnd);
-    Q_UNUSED(destinationParent);
-    Q_UNUSED(destinationRow);
+    Q_UNUSED(sourceParent)
+    Q_UNUSED(sourceStart)
+    Q_UNUSED(sourceEnd)
+    Q_UNUSED(destinationParent)
+    Q_UNUSED(destinationRow)
     /* Disabled for now, layoutAboutToBeChanged() is emitted
     q->beginMoveRows( q->mapFromSource( sourceParent ), sourceStart, sourceEnd,
                       q->mapFromSource( destinationParent ), destinationRow );
@@ -166,8 +168,7 @@ void TodoModel::Private::onLayoutAboutToBeChanged()
     for (const QPersistentModelIndex &persistentIndex : persistentIndexes) {
         m_persistentIndexes << persistentIndex; // Stuff we have to update onLayoutChanged
         Q_ASSERT(persistentIndex.isValid());
-        QModelIndex index_col0 = q->createIndex(persistentIndex.row(), 0,
-                                                persistentIndex.internalPointer());
+        QModelIndex index_col0 = q->createIndex(persistentIndex.row(), 0, persistentIndex.internalPointer());
         const QPersistentModelIndex srcPersistentIndex = q->mapToSource(index_col0);
         Q_ASSERT(srcPersistentIndex.isValid());
         m_layoutChangePersistentIndexes << srcPersistentIndex;
@@ -182,10 +183,7 @@ void TodoModel::Private::onLayoutChanged()
         QModelIndex newIndex_col0 = q->mapFromSource(m_layoutChangePersistentIndexes.at(i));
         Q_ASSERT(newIndex_col0.isValid());
         const int column = m_columns.at(i);
-        QModelIndex newIndex
-            = column == 0
-              ? newIndex_col0
-              : q->createIndex(newIndex_col0.row(), column, newIndex_col0.internalPointer());
+        QModelIndex newIndex = column == 0 ? newIndex_col0 : q->createIndex(newIndex_col0.row(), column, newIndex_col0.internalPointer());
         q->changePersistentIndex(m_persistentIndexes.at(i), newIndex);
     }
 
@@ -219,11 +217,10 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
     Q_ASSERT(sourceIndex.isValid());
-    const Akonadi::Item item
-        = sourceIndex.data(Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+    const Akonadi::Item item = sourceIndex.data(Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
     if (!item.isValid()) {
         qCWarning(CALENDARVIEW_LOG) << "Invalid index: " << sourceIndex;
-        //Q_ASSERT( false );
+        // Q_ASSERT( false );
         return QVariant();
     }
     const KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(item);
@@ -262,24 +259,17 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
         case PercentColumn:
             return QVariant(todo->percentComplete());
         case StartDateColumn:
-            return todo->hasStartDate() ? QLocale().toString(
-                todo->dtStart().toLocalTime().date(), QLocale::ShortFormat)
-                   : QVariant(QString());
+            return todo->hasStartDate() ? QLocale().toString(todo->dtStart().toLocalTime().date(), QLocale::ShortFormat) : QVariant(QString());
         case DueDateColumn:
-            return todo->hasDueDate() ? QLocale().toString(
-                todo->dtDue().toLocalTime().date(), QLocale::ShortFormat)
-                   : QVariant(QString());
-        case CategoriesColumn:
-        {
-            QString categories = todo->categories().join(
-                i18nc("delimiter for joining category names", ","));
+            return todo->hasDueDate() ? QLocale().toString(todo->dtDue().toLocalTime().date(), QLocale::ShortFormat) : QVariant(QString());
+        case CategoriesColumn: {
+            QString categories = todo->categories().join(i18nc("delimiter for joining category/tag names", ","));
             return QVariant(categories);
         }
         case DescriptionColumn:
             return QVariant(todo->description());
         case CalendarColumn:
-            return QVariant(CalendarSupport::displayName(d->m_calendar.data(),
-                                                         item.parentCollection()));
+            return QVariant(CalendarSupport::displayName(d->m_calendar.data(), item.parentCollection()));
         }
         return QVariant();
     }
@@ -303,8 +293,7 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
         case DescriptionColumn:
             return QVariant(todo->description());
         case CalendarColumn:
-            return QVariant(CalendarSupport::displayName(d->m_calendar.data(),
-                                                         item.parentCollection()));
+            return QVariant(CalendarSupport::displayName(d->m_calendar.data(), item.parentCollection()));
         }
         return QVariant();
     }
@@ -312,10 +301,8 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
     // set the tooltip for every item
     if (role == Qt::ToolTipRole) {
         if (d->m_preferences->enableToolTips()) {
-            return QVariant(KCalUtils::IncidenceFormatter::toolTipStr(
-                                CalendarSupport::displayName(d->m_calendar.data(),
-                                                             item.parentCollection()),
-                                todo, QDate(), true));
+            return QVariant(
+                KCalUtils::IncidenceFormatter::toolTipStr(CalendarSupport::displayName(d->m_calendar.data(), item.parentCollection()), todo, QDate(), true));
         } else {
             return QVariant();
         }
@@ -324,11 +311,9 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
     // background colour for todos due today or overdue todos
     if (role == Qt::BackgroundRole) {
         if (todo->isOverdue()) {
-            return QVariant(
-                QBrush(d->m_preferences->todoOverdueColor()));
+            return QVariant(QBrush(d->m_preferences->todoOverdueColor()));
         } else if (isDueToday(todo)) {
-            return QVariant(
-                QBrush(d->m_preferences->todoDueTodayColor()));
+            return QVariant(QBrush(d->m_preferences->todoDueTodayColor()));
         }
     }
 
@@ -357,9 +342,7 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
     // category colour
     if (role == Qt::DecorationRole && index.column() == SummaryColumn) {
         QStringList categories = todo->categories();
-        return categories.isEmpty()
-               ? QVariant()
-               : QVariant(CalendarSupport::KCalPrefs::instance()->categoryColor(categories.first()));
+        return categories.isEmpty() ? QVariant() : QVariant(CalendarSupport::KCalPrefs::instance()->categoryColor(categories.first()));
     } else if (role == Qt::DecorationRole) {
         return QVariant();
     }
@@ -414,13 +397,11 @@ bool TodoModel::setData(const QModelIndex &index, const QVariant &value, int rol
         return true;
     }
 
-    const Akonadi::Item item
-        = data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+    const Akonadi::Item item = data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
     const KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(item);
 
     if (!item.isValid() || !todo) {
-        qCWarning(CALENDARVIEW_LOG)
-            << "TodoModel::setData() called, bug item is invalid or doesn't have payload";
+        qCWarning(CALENDARVIEW_LOG) << "TodoModel::setData() called, bug item is invalid or doesn't have payload";
         Q_ASSERT(false);
         return false;
     }
@@ -430,7 +411,7 @@ bool TodoModel::setData(const QModelIndex &index, const QVariant &value, int rol
         if (role == Qt::CheckStateRole && index.column() == 0) {
             const bool checked = static_cast<Qt::CheckState>(value.toInt()) == Qt::Checked;
             if (checked) {
-                todo->setCompleted(QDateTime::currentDateTimeUtc());    // Because it calls Todo::recurTodo()
+                todo->setCompleted(QDateTime::currentDateTimeUtc()); // Because it calls Todo::recurTodo()
             } else {
                 todo->setCompleted(false);
             }
@@ -449,15 +430,13 @@ bool TodoModel::setData(const QModelIndex &index, const QVariant &value, int rol
             case PercentColumn:
                 todo->setPercentComplete(value.toInt());
                 break;
-            case StartDateColumn:
-            {
+            case StartDateColumn: {
                 QDateTime tmp = todo->dtStart();
                 tmp.setDate(value.toDate());
                 todo->setDtStart(tmp);
                 break;
             }
-            case DueDateColumn:
-            {
+            case DueDateColumn: {
                 QDateTime tmp = todo->dtDue();
                 tmp.setDate(value.toDate());
                 todo->setDtDue(tmp);
@@ -484,7 +463,7 @@ bool TodoModel::setData(const QModelIndex &index, const QVariant &value, int rol
         return true;
     } else {
         if (!(role == Qt::CheckStateRole && index.column() == 0)) {
-            //KOHelper::showSaveIncidenceErrorMsg( 0, todo ); //TODO pass parent
+            // KOHelper::showSaveIncidenceErrorMsg( 0, todo ); //TODO pass parent
             qCCritical(CALENDARVIEW_LOG) << "Unable to modify incidence";
         }
         return false;
@@ -518,77 +497,57 @@ void TodoModel::setSourceModel(QAbstractItemModel *model)
     beginResetModel();
 
     if (sourceModel()) {
-        disconnect(sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                   d, SLOT(onDataChanged(QModelIndex,QModelIndex)));
-        disconnect(sourceModel(), SIGNAL(headerDataChanged(Qt::Orientation,int,int)),
-                   d, SLOT(onHeaderDataChanged(Qt::Orientation,int,int)));
+        disconnect(sourceModel(), SIGNAL(dataChanged(QModelIndex, QModelIndex)), d, SLOT(onDataChanged(QModelIndex, QModelIndex)));
+        disconnect(sourceModel(), SIGNAL(headerDataChanged(Qt::Orientation, int, int)), d, SLOT(onHeaderDataChanged(Qt::Orientation, int, int)));
 
-        disconnect(sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-                   d, SLOT(onRowsInserted(QModelIndex,int,int)));
+        disconnect(sourceModel(), SIGNAL(rowsInserted(QModelIndex, int, int)), d, SLOT(onRowsInserted(QModelIndex, int, int)));
 
-        disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                   d, SLOT(onRowsRemoved(QModelIndex,int,int)));
+        disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)), d, SLOT(onRowsRemoved(QModelIndex, int, int)));
 
-        disconnect(sourceModel(), SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
-                   d, SLOT(onRowsMoved(QModelIndex,int,int,QModelIndex,int)));
+        disconnect(sourceModel(), SIGNAL(rowsMoved(QModelIndex, int, int, QModelIndex, int)), d, SLOT(onRowsMoved(QModelIndex, int, int, QModelIndex, int)));
 
-        disconnect(sourceModel(), SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
-                   d, SLOT(onRowsAboutToBeInserted(QModelIndex,int,int)));
+        disconnect(sourceModel(), SIGNAL(rowsAboutToBeInserted(QModelIndex, int, int)), d, SLOT(onRowsAboutToBeInserted(QModelIndex, int, int)));
 
-        disconnect(sourceModel(), SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-                   d, SLOT(onRowsAboutToBeRemoved(QModelIndex,int,int)));
+        disconnect(sourceModel(), SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)), d, SLOT(onRowsAboutToBeRemoved(QModelIndex, int, int)));
 
-        disconnect(sourceModel(), SIGNAL(modelAboutToBeReset()),
-                   d, SLOT(onModelAboutToBeReset()));
+        disconnect(sourceModel(), SIGNAL(modelAboutToBeReset()), d, SLOT(onModelAboutToBeReset()));
 
-        disconnect(sourceModel(), SIGNAL(modelReset()),
-                   d, SLOT(onModelReset()));
+        disconnect(sourceModel(), SIGNAL(modelReset()), d, SLOT(onModelReset()));
 
-        disconnect(sourceModel(), SIGNAL(layoutAboutToBeChanged()),
-                   d, SLOT(onLayoutAboutToBeChanged()));
+        disconnect(sourceModel(), SIGNAL(layoutAboutToBeChanged()), d, SLOT(onLayoutAboutToBeChanged()));
 
-        disconnect(sourceModel(), SIGNAL(layoutChanged()),
-                   d, SLOT(onLayoutChanged()));
+        disconnect(sourceModel(), SIGNAL(layoutChanged()), d, SLOT(onLayoutChanged()));
     }
 
     QAbstractProxyModel::setSourceModel(model);
 
     if (sourceModel()) {
-        connect(sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                d, SLOT(onDataChanged(QModelIndex,QModelIndex)));
+        connect(sourceModel(), SIGNAL(dataChanged(QModelIndex, QModelIndex)), d, SLOT(onDataChanged(QModelIndex, QModelIndex)));
 
-        connect(sourceModel(), SIGNAL(headerDataChanged(Qt::Orientation,int,int)),
-                d, SLOT(onHeaderDataChanged(Qt::Orientation,int,int)));
+        connect(sourceModel(), SIGNAL(headerDataChanged(Qt::Orientation, int, int)), d, SLOT(onHeaderDataChanged(Qt::Orientation, int, int)));
 
-        connect(sourceModel(), SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
-                d, SLOT(onRowsAboutToBeInserted(QModelIndex,int,int)));
+        connect(sourceModel(), SIGNAL(rowsAboutToBeInserted(QModelIndex, int, int)), d, SLOT(onRowsAboutToBeInserted(QModelIndex, int, int)));
 
-        connect(sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-                d, SLOT(onRowsInserted(QModelIndex,int,int)));
+        connect(sourceModel(), SIGNAL(rowsInserted(QModelIndex, int, int)), d, SLOT(onRowsInserted(QModelIndex, int, int)));
 
-        connect(sourceModel(), SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-                d, SLOT(onRowsAboutToBeRemoved(QModelIndex,int,int)));
+        connect(sourceModel(), SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)), d, SLOT(onRowsAboutToBeRemoved(QModelIndex, int, int)));
 
-        connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                d, SLOT(onRowsRemoved(QModelIndex,int,int)));
+        connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)), d, SLOT(onRowsRemoved(QModelIndex, int, int)));
 
-        connect(sourceModel(), SIGNAL(rowsAboutToBeMoved(QModelIndex,int,int,QModelIndex,int)),
-                d, SLOT(onRowsAboutToBeMoved(QModelIndex,int,int,QModelIndex,int)));
+        connect(sourceModel(),
+                SIGNAL(rowsAboutToBeMoved(QModelIndex, int, int, QModelIndex, int)),
+                d,
+                SLOT(onRowsAboutToBeMoved(QModelIndex, int, int, QModelIndex, int)));
 
-        connect(sourceModel(), SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
-                d, SLOT(onRowsMoved(QModelIndex,int,int,QModelIndex,int)));
+        connect(sourceModel(), SIGNAL(rowsMoved(QModelIndex, int, int, QModelIndex, int)), d, SLOT(onRowsMoved(QModelIndex, int, int, QModelIndex, int)));
 
-        connect(sourceModel(), SIGNAL(modelAboutToBeReset()),
-                d, SLOT(onModelAboutToBeReset()));
+        connect(sourceModel(), SIGNAL(modelAboutToBeReset()), d, SLOT(onModelAboutToBeReset()));
 
-        connect(sourceModel(), SIGNAL(modelReset()),
-                d, SLOT(onModelReset()));
+        connect(sourceModel(), SIGNAL(modelReset()), d, SLOT(onModelReset()));
 
-        connect(sourceModel(), SIGNAL(layoutAboutToBeChanged()),
-                d, SLOT(onLayoutAboutToBeChanged()));
+        connect(sourceModel(), SIGNAL(layoutAboutToBeChanged()), d, SLOT(onLayoutAboutToBeChanged()));
 
-        connect(sourceModel(), SIGNAL(layoutChanged()),
-                d, SLOT(onLayoutChanged()));
+        connect(sourceModel(), SIGNAL(layoutChanged()), d, SLOT(onLayoutChanged()));
     }
 
     endResetModel();
@@ -620,7 +579,7 @@ QVariant TodoModel::headerData(int column, Qt::Orientation orientation, int role
         case DueDateColumn:
             return QVariant(i18n("Due Date"));
         case CategoriesColumn:
-            return QVariant(i18n("Categories"));
+            return QVariant(i18n("Tags"));
         case DescriptionColumn:
             return QVariant(i18n("Description"));
         case CalendarColumn:
@@ -669,8 +628,7 @@ QMimeData *TodoModel::mimeData(const QModelIndexList &indexes) const
 {
     Akonadi::Item::List items;
     for (const QModelIndex &index : indexes) {
-        const Akonadi::Item item
-            = this->data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+        const Akonadi::Item item = this->data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
         if (item.isValid() && !items.contains(item)) {
             items.push_back(item);
         }
@@ -680,16 +638,15 @@ QMimeData *TodoModel::mimeData(const QModelIndexList &indexes) const
 
 bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent)
 {
-    Q_UNUSED(row);
-    Q_UNUSED(column);
+    Q_UNUSED(row)
+    Q_UNUSED(column)
 
     if (action != Qt::MoveAction) {
-        qCWarning(CALENDARVIEW_LOG) << "No action other than MoveAction currently supported!"; //TODO
+        qCWarning(CALENDARVIEW_LOG) << "No action other than MoveAction currently supported!"; // TODO
         return false;
     }
 
-    if (d->m_calendar && d->m_changer
-        && (KCalUtils::ICalDrag::canDecode(data) || KCalUtils::VCalDrag::canDecode(data))) {
+    if (d->m_calendar && d->m_changer && (KCalUtils::ICalDrag::canDecode(data) || KCalUtils::VCalDrag::canDecode(data))) {
         KCalUtils::DndFactory dndFactory(d->m_calendar);
         KCalendarCore::Todo::Ptr t = dndFactory.createDropTodo(data);
         KCalendarCore::Event::Ptr e = dndFactory.createDropEvent(data);
@@ -701,8 +658,7 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
             KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(item);
             KCalendarCore::Todo::Ptr destTodo;
             if (parent.isValid()) {
-                const Akonadi::Item parentItem
-                    = this->data(parent, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+                const Akonadi::Item parentItem = this->data(parent, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
                 if (parentItem.isValid()) {
                     destTodo = CalendarSupport::todo(parentItem);
                 }
@@ -710,11 +666,11 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
 
             KCalendarCore::Incidence::Ptr tmp = destTodo;
             while (tmp) {
-                if (tmp->uid() == todo->uid()) {   //correct, don't use instanceIdentifier() here
-                    KMessageBox::information(
-                        nullptr,
-                        i18n("Cannot move to-do to itself or a child of itself."),
-                        i18n("Drop To-do"), QStringLiteral("NoDropTodoOntoItself"));
+                if (tmp->uid() == todo->uid()) { // correct, don't use instanceIdentifier() here
+                    KMessageBox::information(nullptr,
+                                             i18n("Cannot move to-do to itself or a child of itself."),
+                                             i18n("Drop To-do"),
+                                             QStringLiteral("NoDropTodoOntoItself"));
                     return false;
                 }
                 const QString parentUid = tmp->relatedTo();
@@ -742,8 +698,7 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
                 return false;
             }
 
-            const Akonadi::Item parentItem
-                = this->data(parent, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+            const Akonadi::Item parentItem = this->data(parent, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
             KCalendarCore::Todo::Ptr destTodo = CalendarSupport::todo(parentItem);
 
             if (data->hasText()) {
@@ -755,11 +710,9 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
                     destTodo->addAttachment(KCalendarCore::Attachment(text));
                 } else {
                     QStringList emails = KEmailAddress::splitAddressList(text);
-                    for (QStringList::ConstIterator it = emails.constBegin();
-                         it != emails.constEnd(); ++it) {
+                    for (QStringList::ConstIterator it = emails.constBegin(); it != emails.constEnd(); ++it) {
                         QString name, email, comment;
-                        if (KEmailAddress::splitAddress(*it, name, email, comment)
-                            == KEmailAddress::AddressOk) {
+                        if (KEmailAddress::splitAddress(*it, name, email, comment) == KEmailAddress::AddressOk) {
                             destTodo->addAttendee(KCalendarCore::Attendee(name, email));
                         }
                     }
@@ -781,8 +734,7 @@ Qt::ItemFlags TodoModel::flags(const QModelIndex &index) const
 
     Qt::ItemFlags ret = QAbstractItemModel::flags(index);
 
-    const Akonadi::Item item
-        = data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+    const Akonadi::Item item = data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
 
     if (!item.isValid()) {
         Q_ASSERT(mapToSource(index).isValid());
@@ -818,8 +770,7 @@ Qt::ItemFlags TodoModel::flags(const QModelIndex &index) const
         // whole rows should have checkboxes, so append the flag for the
         // first item of every row only. Also, only the first item of every
         // row should be used as a target for a drag and drop operation.
-        ret |= Qt::ItemIsUserCheckable
-               |Qt::ItemIsDropEnabled;
+        ret |= Qt::ItemIsUserCheckable | Qt::ItemIsDropEnabled;
     }
     return ret;
 }
@@ -827,7 +778,7 @@ Qt::ItemFlags TodoModel::flags(const QModelIndex &index) const
 QModelIndex TodoModel::mapFromSource(const QModelIndex &sourceIndex) const
 {
     if (!sourceModel() || !sourceIndex.isValid()) {
-        return QModelIndex();
+        return {};
     }
 
     Q_ASSERT(sourceIndex.internalPointer());
@@ -838,20 +789,18 @@ QModelIndex TodoModel::mapFromSource(const QModelIndex &sourceIndex) const
 QModelIndex TodoModel::mapToSource(const QModelIndex &proxyIndex) const
 {
     if (!sourceModel() || !proxyIndex.isValid()) {
-        return QModelIndex();
+        return {};
     }
 
     if (proxyIndex.column() != 0) {
-        qCCritical(CALENDARVIEW_LOG)
-            << "Map to source called with column>0, but source model only has 1 column";
+        qCCritical(CALENDARVIEW_LOG) << "Map to source called with column>0, but source model only has 1 column";
         Q_ASSERT(false);
     }
 
     Q_ASSERT(proxyIndex.internalPointer());
 
     // we convert to column 0
-    const QModelIndex sourceIndex = SourceModelIndex(proxyIndex.row(), 0,
-                                                     proxyIndex.internalPointer(), sourceModel());
+    const QModelIndex sourceIndex = SourceModelIndex(proxyIndex.row(), 0, proxyIndex.internalPointer(), sourceModel());
 
     return sourceIndex;
 }
@@ -863,14 +812,10 @@ QModelIndex TodoModel::index(int row, int column, const QModelIndex &parent) con
     }
 
     Q_ASSERT(!parent.isValid() || parent.internalPointer());
-    QModelIndex parent_col0
-        = parent.isValid()
-          ? createIndex(parent.row(), 0, parent.internalPointer())
-          : QModelIndex();
+    QModelIndex parent_col0 = parent.isValid() ? createIndex(parent.row(), 0, parent.internalPointer()) : QModelIndex();
 
     // Lets preserve the original internalPointer
-    const QModelIndex index
-        = mapFromSource(sourceModel()->index(row, 0, mapToSource(parent_col0)));
+    const QModelIndex index = mapFromSource(sourceModel()->index(row, 0, mapToSource(parent_col0)));
 
     Q_ASSERT(!index.isValid() || index.internalPointer());
 
@@ -878,7 +823,7 @@ QModelIndex TodoModel::index(int row, int column, const QModelIndex &parent) con
         return createIndex(row, column, index.internalPointer());
     }
 
-    return QModelIndex();
+    return {};
 }
 
 QModelIndex TodoModel::parent(const QModelIndex &child) const
@@ -892,11 +837,11 @@ QModelIndex TodoModel::parent(const QModelIndex &child) const
     QModelIndex parentIndex = mapFromSource(sourceModel()->parent(mapToSource(child_col0)));
 
     Q_ASSERT(!parentIndex.isValid() || parentIndex.internalPointer());
-    if (parentIndex.isValid()) {   // preserve original column
+    if (parentIndex.isValid()) { // preserve original column
         return createIndex(parentIndex.row(), child.column(), parentIndex.internalPointer());
     }
 
-    return QModelIndex();
+    return {};
 }
 
 QModelIndex TodoModel::buddy(const QModelIndex &index) const
